import { ApexCodeCoverage } from './tsforce/tsforce'

export default function format(sfdxCoverage: any, coverageResponse: Array<ApexCodeCoverage>, basePath: string): string {
  let body = 'TN:\n'

  let coverageMap: Map<String, Map<number, number>> = new Map<String, Map<number, number>>()

  sfdxCoverage.coverage.coverage.forEach((apexClass) => {
    let path: string

    if (apexClass.id.startsWith('01p')) {
      path = process.env.PWD + '/' + basePath + 'classes/' + apexClass.name + '.cls'
    } else {
      path = process.env.PWD + '/' + basePath + 'triggers/' + apexClass.name + '.trigger'
    }
    coverageMap.set(path, new Map<number, number>())

    for (var key in apexClass.lines) {
      coverageMap.get(path).set(parseInt(key), 0)
    }
  })

  coverageResponse.forEach((coverage) => {
    let path: string

    if (coverage.ApexClassOrTrigger.Id.startsWith('01p')) {
      path = process.env.PWD + '/' + basePath + 'classes/' + coverage.ApexClassOrTrigger.Name + '.cls'
    } else {
      path = process.env.PWD + '/' + basePath + 'triggers/' + coverage.ApexClassOrTrigger.Name + '.trigger'
    }

    coverage.Coverage.coveredLines.forEach((lineNo) => {
      coverageMap.get(path).set(lineNo, coverageMap.get(path).get(lineNo) + 1)
    })

  })

  coverageMap.forEach((value, key) =>  {
    console.log('Add coverage for ' + key + '...')

    body += 'SF:' + key + '\n'

    value.forEach((value, key) =>  {
      body += 'DA:' + key + ',' + value + '\n'
    })
    body += 'end_of_record\n'
  })

  return body
}